@@ -46,6 +46,8 @@ class DashboardFilter(DynatraceObject):
         return self._management_zone
 
     def _create_from_raw_data(self, raw_element):
+        if raw_element is None:
+            raw_element = {}
         self._timeframe = raw_element.get("timeframe")
         self._management_zone = (
             EntityShortRepresentation(self._http_client, None, raw_element.get("managementZone")) if raw_element.get("managementZone") else None
@@ -79,10 +81,6 @@ class DashboardMetadata(DynatraceObject):
     def owner(self) -> str:
         return self._owner
 
-    @property
-    def sharing_details(self) -> SharingInfo:
-        return self._sharing_details
-
     @property
     def dashboard_filter(self):
         return self._dashboard_filter
@@ -95,19 +93,14 @@ class DashboardMetadata(DynatraceObject):
     def preset(self) -> bool:
         return self._preset
 
-    @property
-    def valid_filter_keys(self) -> List[str]:
-        return self._valid_filter_keys
-
     def _create_from_raw_data(self, raw_element):
+        # TODO - Schema changed, add extra fields dynamicFilters
         self._name = raw_element.get("name")
         self._shared = raw_element.get("shared")
         self._owner = raw_element.get("owner")
-        self._sharing_details = SharingInfo(self._http_client, None, raw_element.get("sharingDetails"))
         self._dashboard_filter = DashboardFilter(self._http_client, None, raw_element.get("dashboardFilter"))
         self._tags = raw_element.get("tags")
         self._preset = raw_element.get("preset")
-        self._valid_filter_keys = raw_element.get("validFilterKeys")
 
 
 class Dashboard(DynatraceObject):
@@ -124,6 +117,8 @@ class Dashboard(DynatraceObject):
         return self._tiles
 
     def _create_from_raw_data(self, raw_element):
+        if raw_element is None:
+            raw_element = {}
         self._id = raw_element.get("id")
         self._dashboard_metadata = DashboardMetadata(self._http_client, None, raw_element.get("dashboardMetadata"))
         self._tiles = [Tile(self._http_client, None, raw_tile) for raw_tile in raw_element.get("tiles", [])]
